@@ -1,4 +1,6 @@
 from azure.storage.blob import BlobServiceClient
+from azure.core.exceptions import ResourceExistsError
+from azure.storage.blob import ContentSettings
 
 
 class GossAzureBlobClient(object):
@@ -6,6 +8,7 @@ class GossAzureBlobClient(object):
     def __init__(self, secret_id, secret_key, region, bucket):
         self._client = BlobServiceClient.from_connection_string(conn_str=secret_id)
         self._bucket = bucket
+        self._region = region
 
     def _blob_client(self, container_name, blob_name):
         return self._client.get_blob_client(container_name, blob_name)
@@ -20,9 +23,17 @@ class GossAzureBlobClient(object):
         """
         Upload object to azure cloud
         """
-        blob_client = self._blob_client(self._bucket, key)
-        with open(local_path, "rb") as data:
-            blob_client.upload_blob(data)
+        try:
+            blob_client = self._blob_client(self._bucket, key)
+            with open(local_path, "rb") as data:
+                if self._region:
+                    blob_client.upload_blob(data, content_settings=ContentSettings(content_type=self._region))
+                else:
+                    blob_client.upload_blob(data)
+        except Exception as err:
+            if not isinstance(err, ResourceExistsError):
+                return "", err
+        return self._get_object_url(key), None
 
     def _list_objects(self, prefix):
         """
